@@ -1,6 +1,6 @@
 #!/bin/sh
 
-SERVER=/usr/bin/sj3serv
+SERVER=/usr/sbin/sj3serv
 KILLER="killall sj3serv"
 LOCKD=/var/lock/subsys
 
